@@ -8,7 +8,7 @@
 
 #include <asm/types.h>		/* For __uXX types */
 
-#define IP_VS_VERSION_CODE	0x010102
+#define IP_VS_VERSION_CODE	0x010103
 #define NVERSION(version)			\
 	(version >> 16) & 0xFF,			\
 	(version >> 8) & 0xFF,			\
@@ -903,6 +903,8 @@ static inline void ip_vs_service_put(struct ip_vs_service *svc)
 
 extern struct ip_vs_dest *
 ip_vs_lookup_real_service(__u16 protocol, __u32 daddr, __u16 dport);
+extern int ip_vs_use_count_inc(void);
+extern void ip_vs_use_count_dec(void);
 extern void update_defense_level(void);
 extern int ip_vs_control_init(void);
 extern void ip_vs_control_cleanup(void);
