@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_ctl.c,v 1.33 2002/12/19 08:40:52 wensong Exp $
+ * Version:     $Id: ip_vs_ctl.c,v 1.34 2003/03/22 06:31:21 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -211,6 +211,19 @@ void update_defense_level(void)
 }
 
 
+int
+ip_vs_use_count_inc(void)
+{
+	return try_module_get(THIS_MODULE);
+}
+
+void
+ip_vs_use_count_dec(void)
+{
+	module_put(THIS_MODULE);
+}
+
+
 /*
  *	Hash table: for virtual service lookups
  */
@@ -994,12 +1007,13 @@ ip_vs_add_service(struct ip_vs_service_user *u, struct ip_vs_service **svc_p)
 	struct ip_vs_scheduler *sched = NULL;
 	struct ip_vs_service *svc = NULL;
 
-	MOD_INC_USE_COUNT;
+	/* increase the module use count */
+	ip_vs_use_count_inc();
 
 	/* Lookup the scheduler by 'u->sched_name' */
 	sched = ip_vs_scheduler_get(u->sched_name);
 	if (sched == NULL) {
-		IP_VS_INFO("Scheduler module ip_vs_%s.o not found\n",
+		IP_VS_INFO("Scheduler module ip_vs_%s not found\n",
 			   u->sched_name);
 		ret = -ENOENT;
 		goto out_mod_dec;
@@ -1065,8 +1079,11 @@ ip_vs_add_service(struct ip_vs_service_user *u, struct ip_vs_service **svc_p)
 		kfree(svc);
 	}
 	ip_vs_scheduler_put(sched);
+
   out_mod_dec:
-	MOD_DEC_USE_COUNT;
+	/* decrease the module use count */
+	ip_vs_use_count_dec();
+
 	return ret;
 }
 
@@ -1085,7 +1102,7 @@ ip_vs_edit_service(struct ip_vs_service *svc, struct ip_vs_service_user *u)
 	 */
 	sched = ip_vs_scheduler_get(u->sched_name);
 	if (sched == NULL) {
-		IP_VS_INFO("Scheduler module ip_vs_%s.o not found\n",
+		IP_VS_INFO("Scheduler module ip_vs_%s not found\n",
 			   u->sched_name);
 		return -ENOENT;
 	}
@@ -1159,13 +1176,11 @@ static void __ip_vs_del_service(struct ip_vs_service *svc)
 	ip_vs_num_services--;
 	ip_vs_kill_estimator(&svc->stats);
 
-	/*
-	 *    Unbind scheduler
-	 */
+	/* Unbind scheduler */
 	old_sched = svc->scheduler;
 	ip_vs_unbind_scheduler(svc);
-	if (old_sched && old_sched->module)
-		__MOD_DEC_USE_COUNT(old_sched->module);
+	if (old_sched)
+		ip_vs_scheduler_put(old_sched);
 
 	/* Unbind app inc */
 	if (svc->inc) {
@@ -1196,7 +1211,9 @@ static void __ip_vs_del_service(struct ip_vs_service *svc)
 	 */
 	if (atomic_read(&svc->refcnt) == 0)
 		kfree(svc);
-	MOD_DEC_USE_COUNT;
+
+	/* decrease the module use count */
+	ip_vs_use_count_dec();
 }
 
 /*
@@ -1740,7 +1757,9 @@ do_ip_vs_set_ctl(struct sock *sk, int cmd, void *user, unsigned int len)
 	if (copy_from_user(arg, user, len) != 0)
 		return -EFAULT;
 
-	MOD_INC_USE_COUNT;
+	/* increase the module use count */
+	ip_vs_use_count_inc();
+
 	if (down_interruptible(&__ip_vs_mutex)) {
 		ret = -ERESTARTSYS;
 		goto out_dec;
@@ -1833,7 +1852,8 @@ do_ip_vs_set_ctl(struct sock *sk, int cmd, void *user, unsigned int len)
   out_unlock:
 	up(&__ip_vs_mutex);
   out_dec:
-	MOD_DEC_USE_COUNT;
+	/* decrease the module use count */
+	ip_vs_use_count_dec();
 
 	return ret;
 }
@@ -2160,6 +2180,7 @@ int ip_vs_control_init(void)
 	return 0;
 }
 
+
 void ip_vs_control_cleanup(void)
 {
 	EnterFunction(2);
