@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_sched.c,v 1.11 2001/11/04 08:58:43 wensong Exp $
+ * Version:     $Id: ip_vs_sched.c,v 1.12 2003/03/22 06:31:21 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -121,9 +121,9 @@ static struct ip_vs_scheduler *ip_vs_sched_getbyname(const char *sched_name)
 		sched = list_entry(e, struct ip_vs_scheduler, n_list);
 
 		/*
-		 * Test and MOD_INC_USE_COUNT atomically
+		 * Test and get the modules atomically
 		 */
-		if (sched->module && !try_inc_mod_count(sched->module)) {
+		if (sched->module && !try_module_get(sched->module)) {
 			/*
 			 * This scheduler is just deleted
 			 */
@@ -135,7 +135,7 @@ static struct ip_vs_scheduler *ip_vs_sched_getbyname(const char *sched_name)
 			return sched;
 		}
 		if (sched->module)
-			__MOD_DEC_USE_COUNT(sched->module);
+			module_put(sched->module);
 	}
 
 	read_unlock_bh(&__ip_vs_sched_lock);
@@ -171,7 +171,7 @@ struct ip_vs_scheduler *ip_vs_scheduler_get(const char *sched_name)
 void ip_vs_scheduler_put(struct ip_vs_scheduler *scheduler)
 {
 	if (scheduler->module)
-		__MOD_DEC_USE_COUNT(scheduler->module);
+		module_put(scheduler->module);
 }
 
 
@@ -192,7 +192,8 @@ int register_ip_vs_scheduler(struct ip_vs_scheduler *scheduler)
 		return -EINVAL;
 	}
 
-	MOD_INC_USE_COUNT;
+	/* increase the module use count */
+	ip_vs_use_count_inc();
 
 	/*
 	 *  Make sure that the scheduler with this name doesn't exist
@@ -201,7 +202,7 @@ int register_ip_vs_scheduler(struct ip_vs_scheduler *scheduler)
 	sched = ip_vs_sched_getbyname(scheduler->name);
 	if (sched) {
 		ip_vs_scheduler_put(sched);
-		MOD_DEC_USE_COUNT;
+		ip_vs_use_count_dec();
 		IP_VS_ERR("register_ip_vs_scheduler(): [%s] scheduler "
 			  "already existed in the system\n", scheduler->name);
 		return -EINVAL;
@@ -211,7 +212,7 @@ int register_ip_vs_scheduler(struct ip_vs_scheduler *scheduler)
 
 	if (scheduler->n_list.next != &scheduler->n_list) {
 		write_unlock_bh(&__ip_vs_sched_lock);
-		MOD_DEC_USE_COUNT;
+		ip_vs_use_count_dec();
 		IP_VS_ERR("register_ip_vs_scheduler(): [%s] scheduler "
 			  "already linked\n", scheduler->name);
 		return -EINVAL;
@@ -253,7 +254,8 @@ int unregister_ip_vs_scheduler(struct ip_vs_scheduler *scheduler)
 	list_del(&scheduler->n_list);
 	write_unlock_bh(&__ip_vs_sched_lock);
 
-	MOD_DEC_USE_COUNT;
+	/* decrease the module use count */
+	ip_vs_use_count_dec();
 
 	IP_VS_INFO("[%s] scheduler unregistered.\n", scheduler->name);
 
