@@ -1,7 +1,7 @@
 /*
  * IPVS:        Weighted Least-Connection Scheduling module
  *
- * Version:     $Id: ip_vs_wlc.c,v 1.11 2002/09/15 08:14:08 wensong Exp $
+ * Version:     $Id: ip_vs_wlc.c,v 1.12 2003/03/22 06:31:21 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -53,6 +53,13 @@ ip_vs_wlc_update_svc(struct ip_vs_service *svc)
 }
 
 
+static unsigned int
+ip_vs_wlc_dest_overhead(struct ip_vs_dest *dest)
+{
+	return (atomic_read(&dest->activeconns) << 8) +
+		atomic_read(&dest->inactconns);
+}
+
 /*
  *    Weighted Least Connection scheduling
  */
@@ -61,16 +68,16 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 {
 	register struct list_head *l, *e;
 	struct ip_vs_dest *dest, *least;
-	int loh, doh;
+	unsigned int loh, doh;
 
 	IP_VS_DBG(6, "ip_vs_wlc_schedule(): Scheduling...\n");
 
 	/*
-	 * We think the overhead of processing active connections is fifty
+	 * We think the overhead of processing active connections is 256
 	 * times higher than that of inactive connections in average. (This
-	 * fifty times might not be accurate, we will change it later.) We
+	 * 256 times might not be accurate, we will change it later.) We
 	 * use the following formula to estimate the overhead:
-	 *		  dest->activeconns*50 + dest->inactconns
+	 *		  dest->activeconns*256 + dest->inactconns
 	 * and the load:
 	 *		  (dest overhead) / dest->weight
 	 *
@@ -88,8 +95,7 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 		least = list_entry(e, struct ip_vs_dest, n_list);
 		if (!(least->flags & IP_VS_DEST_F_OVERLOAD) &&
 		    atomic_read(&least->weight) > 0) {
-			loh = atomic_read(&least->activeconns) * 50
-				+ atomic_read(&least->inactconns);
+			loh = ip_vs_wlc_dest_overhead(least);
 			goto nextstage;
 		}
 	}
@@ -104,8 +110,7 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 
 		if (dest->flags & IP_VS_DEST_F_OVERLOAD)
 			continue;
-		doh = atomic_read(&dest->activeconns) * 50
-			+ atomic_read(&dest->inactconns);
+		doh = ip_vs_wlc_dest_overhead(dest);
 		if (loh * atomic_read(&dest->weight) >
 		    doh * atomic_read(&least->weight)) {
 			least = dest;
